summaryrefslogtreecommitdiffstats
path: root/kio/kio/kdirlister.cpp
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-01-03 04:12:51 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-01-03 04:12:51 +0000
commit560378aaca1784ba19806a0414a32b20c744de39 (patch)
treece0dfd7c3febf2a1adc7603d1019a8be2083c415 /kio/kio/kdirlister.cpp
parentd4d5af1cdbd3cc65d095e0afc5b1f4260091cf5d (diff)
downloadtdelibs-560378aaca1784ba19806a0414a32b20c744de39.tar.gz
tdelibs-560378aaca1784ba19806a0414a32b20c744de39.zip
Automated conversion for enhanced compatibility with TQt for Qt4 3.4.0 TP1
NOTE: This will not compile with Qt4 (yet), however it does compile with Qt3 git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdelibs@1211081 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kio/kio/kdirlister.cpp')
-rw-r--r--kio/kio/kdirlister.cpp50
1 files changed, 25 insertions, 25 deletions
diff --git a/kio/kio/kdirlister.cpp b/kio/kio/kdirlister.cpp
index 901f382b8..5664e2572 100644
--- a/kio/kio/kdirlister.cpp
+++ b/kio/kio/kdirlister.cpp
@@ -113,7 +113,7 @@ bool KDirListerCache::listDir( KDirLister *lister, const KURL& _u,
lister->d->rootFileItem = 0;
}
- else if ( lister->d->lstDirs.find( _url ) != lister->d->lstDirs.end() )
+ else if ( lister->d->lstDirs.tqfind( _url ) != lister->d->lstDirs.end() )
{
// stop the job listing _url for this lister
stop( lister, _url );
@@ -311,7 +311,7 @@ void KDirListerCache::stop( KDirLister *lister )
TQPtrList<KDirLister> *listers;
while ( (listers = it.current()) )
{
- if ( listers->findRef( lister ) > -1 )
+ if ( listers->tqfindRef( lister ) > -1 )
{
// lister is listing url
TQString url = it.currentKey();
@@ -456,8 +456,8 @@ void KDirListerCache::forgetDirs( KDirLister *lister, const KURL& _url, bool not
// remove the dir from lister->d->lstDirs so that it doesn't contain things
// that itemsInUse doesn't. When emitting the canceled signals lstDirs must
// not contain anything that itemsInUse does not contain. (otherwise it
- // might crash in findByName()).
- lister->d->lstDirs.remove( lister->d->lstDirs.find( url ) );
+ // might crash in tqfindByName()).
+ lister->d->lstDirs.remove( lister->d->lstDirs.tqfind( url ) );
DirItem *item = itemsInUse[urlStr];
@@ -498,7 +498,7 @@ void KDirListerCache::forgetDirs( KDirLister *lister, const KURL& _url, bool not
// unmounting a removable device (#37780)
const bool isLocal = item->url.isLocalFile();
const bool isManuallyMounted = isLocal && KIO::manually_mounted( item->url.path() );
- bool containsManuallyMounted = false;
+ bool tqcontainsManuallyMounted = false;
if ( !isManuallyMounted && item->lstItems && isLocal )
{
// Look for a manually-mounted directory inside
@@ -506,15 +506,15 @@ void KDirListerCache::forgetDirs( KDirLister *lister, const KURL& _url, bool not
// I hope this isn't too slow (manually_mounted caches the last device so most
// of the time this is just a stat per subdir)
KFileItemListIterator kit( *item->lstItems );
- for ( ; kit.current() && !containsManuallyMounted; ++kit )
+ for ( ; kit.current() && !tqcontainsManuallyMounted; ++kit )
if ( (*kit)->isDir() && KIO::manually_mounted( (*kit)->url().path() ) )
- containsManuallyMounted = true;
+ tqcontainsManuallyMounted = true;
}
- if ( isManuallyMounted || containsManuallyMounted )
+ if ( isManuallyMounted || tqcontainsManuallyMounted )
{
kdDebug(7004) << "Not adding a watch on " << item->url << " because it " <<
- ( isManuallyMounted ? "is manually mounted" : "contains a manually mounted subdir" ) << endl;
+ ( isManuallyMounted ? "is manually mounted" : "tqcontains a manually mounted subdir" ) << endl;
item->complete = false; // set to "dirty"
}
else
@@ -570,7 +570,7 @@ void KDirListerCache::updateDirectory( const KURL& _dir )
}
kdDebug(7004) << k_funcinfo << "Killed = " << killed << endl;
- // we don't need to emit canceled signals since we only replaced the job,
+ // we don't need to emit canceled signals since we only tqreplaced the job,
// the listing is continuing.
Q_ASSERT( !listers || (listers && killed) );
@@ -645,7 +645,7 @@ KFileItemList *KDirListerCache::itemsForDir( const KURL &_dir ) const
return item ? item->lstItems : 0;
}
-KFileItem *KDirListerCache::findByName( const KDirLister *lister, const TQString& _name ) const
+KFileItem *KDirListerCache::tqfindByName( const KDirLister *lister, const TQString& _name ) const
{
Q_ASSERT( lister );
@@ -669,8 +669,8 @@ KFileItem *KDirListerCache::findByURL( const KDirLister *lister, const KURL& _u
KURL parentDir( _url );
parentDir.setPath( parentDir.directory() );
- // If lister is set, check that it contains this dir
- if ( lister && !lister->d->lstDirs.contains( parentDir ) )
+ // If lister is set, check that it tqcontains this dir
+ if ( lister && !lister->d->lstDirs.tqcontains( parentDir ) )
return 0L;
KFileItemList *itemList = itemsForDir( parentDir );
@@ -760,7 +760,7 @@ void KDirListerCache::FilesChanged( const KURL::List &fileList )
// Let's update the dir.
KURL dir( *it );
dir.setPath( dir.directory( true ) );
- if ( dirsToUpdate.find( dir ) == dirsToUpdate.end() )
+ if ( dirsToUpdate.tqfind( dir ) == dirsToUpdate.end() )
dirsToUpdate.prepend( dir );
}
}
@@ -959,7 +959,7 @@ void KDirListerCache::slotEntries( KIO::Job *job, const KIO::UDSEntryList &entri
{
TQString name;
// find out about the name
KIO::UDSEntry::ConstIterator entit = (*it).begin();
for( ; entit != (*it).end(); ++entit )
if ( (*entit).m_uds == KIO::UDS_NAME )
@@ -1110,7 +1110,7 @@ void KDirListerCache::slotRedirection( KIO::Job *j, const KURL& url )
kdl->d->url = newUrl;
}
- *kdl->d->lstDirs.find( oldUrl ) = newUrl;
+ *kdl->d->lstDirs.tqfind( oldUrl ) = newUrl;
if ( kdl->d->lstDirs.count() == 1 )
{
@@ -1147,7 +1147,7 @@ void KDirListerCache::slotRedirection( KIO::Job *j, const KURL& url )
kdl->d->url = newUrl;
}
- *kdl->d->lstDirs.find( oldUrl ) = newUrl;
+ *kdl->d->lstDirs.tqfind( oldUrl ) = newUrl;
if ( kdl->d->lstDirs.count() == 1 )
{
@@ -1429,7 +1429,7 @@ void KDirListerCache::emitRedirections( const KURL &oldUrl, const KURL &url )
// And notify the dirlisters of the redirection
for ( KDirLister *kdl = holders->first(); kdl; kdl = holders->next() )
{
- *kdl->d->lstDirs.find( oldUrl ) = url;
+ *kdl->d->lstDirs.tqfind( oldUrl ) = url;
if ( kdl->d->lstDirs.count() == 1 )
emit kdl->redirection( url );
@@ -1478,7 +1478,7 @@ void KDirListerCache::slotUpdateResult( KIO::Job * j )
if ( listers )
for ( kdl = tmpLst->first(); kdl; kdl = tmpLst->next() )
{
- Q_ASSERT( listers->containsRef( kdl ) == 0 );
+ Q_ASSERT( listers->tqcontainsRef( kdl ) == 0 );
listers->append( kdl );
}
else
@@ -1755,7 +1755,7 @@ void KDirListerCache::deleteDir( const KURL& dirUrl )
DirItem *dir = itemsInUse.take( deletedUrl.url() );
Q_ASSERT( !dir );
- if ( !dir ) // take didn't find it - move on
+ if ( !dir ) // take didn't tqfind it - move on
++itu;
}
else
@@ -2049,13 +2049,13 @@ KFileItem *KDirLister::findByURL( const KURL& _url ) const
return s_pCache->findByURL( this, _url );
}
-KFileItem *KDirLister::findByName( const TQString& _name ) const
+KFileItem *KDirLister::tqfindByName( const TQString& _name ) const
{
- return s_pCache->findByName( this, _name );
+ return s_pCache->tqfindByName( this, _name );
}
#ifndef KDE_NO_COMPAT
-KFileItem *KDirLister::find( const KURL& _url ) const
+KFileItem *KDirLister::tqfind( const KURL& _url ) const
{
return findByURL( _url );
}
@@ -2095,8 +2095,8 @@ void KDirLister::setMimeFilter( const TQStringList& mimeFilter )
if ( !(d->changes & MIME_FILTER) )
d->oldMimeFilter = d->mimeFilter;
- if ( mimeFilter.find("all/allfiles") != mimeFilter.end() ||
- mimeFilter.find("all/all") != mimeFilter.end() )
+ if ( mimeFilter.tqfind("all/allfiles") != mimeFilter.end() ||
+ mimeFilter.tqfind("all/all") != mimeFilter.end() )
d->mimeFilter.clear();
else
d->mimeFilter = mimeFilter;
@@ -959,7 +959,7 @@ void KDirListerCache::slotEntries( KIO::Job *job, const KIO::UDSEntryList &entri
{
TQString name;
- // find out about the name
+ // tqfind out about the name
KIO::UDSEntry::ConstIterator entit = (*it).begin();
for( ; entit != (*it).end(); ++entit )